Addon class

An Amazon EKS add-on.

Constructors

Addon({String? addonArn, String? addonName, String? addonVersion, String? clusterName, DateTime? createdAt, AddonHealth? health, DateTime? modifiedAt, String? serviceAccountRoleArn, AddonStatus? status, Map<String, String>? tags})
Addon.fromJson(Map<String, dynamic> json)
factory

Properties

addonArn → String?
The Amazon Resource Name (ARN) of the add-on.
final
addonName → String?
The name of the add-on.
final
addonVersion → String?
The version of the add-on.
final
clusterName → String?
The name of the cluster.
final
createdAt → DateTime?
The date and time that the add-on was created.
final
hashCode → int
The hash code for this object.
no setterinherited
health → AddonHealth?
An object that represents the health of the add-on.
final
modifiedAt → DateTime?
The date and time that the add-on was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountRoleArn → String?
The Amazon Resource Name (ARN) of the IAM role that is bound to the Kubernetes service account used by the add-on.
final
status → AddonStatus?
The status of the add-on.
final
tags → Map<String, String>?
The metadata that you apply to the cluster to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Cluster tags do not propagate to any other resources associated with the cluster.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited