AddonInfo class

Information about an add-on.

Constructors

AddonInfo({String? addonName, List<AddonVersionInfo>? addonVersions, String? type})
AddonInfo.fromJson(Map<String, dynamic> json)
factory

Properties

addonName → String?
The name of the add-on.
final
addonVersions → List<AddonVersionInfo>?
An object that represents information about available add-on versions and compatible Kubernetes versions.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of the add-on.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited