AddonIssue class

An issue related to an add-on.

Constructors

AddonIssue({AddonIssueCode? code, String? message, List<String>? resourceIds})
AddonIssue.fromJson(Map<String, dynamic> json)
factory

Properties

code → AddonIssueCode?
A code that describes the type of issue.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A message that provides details about the issue and what might cause it.
final
resourceIds → List<String>?
The resource IDs of the issue.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited