AutoScalingGroup class

An Auto Scaling group that is associated with an Amazon EKS managed node group.

Constructors

AutoScalingGroup({String? name})
AutoScalingGroup.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the Auto Scaling group associated with an Amazon EKS managed node group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited