Compatibility class

Compatibility information.

Constructors

Compatibility({String? clusterVersion, bool? defaultVersion, List<String>? platformVersions})
Compatibility.fromJson(Map<String, dynamic> json)
factory

Properties

clusterVersion → String?
The supported Kubernetes version of the cluster.
final
defaultVersion → bool?
The supported default version.
final
hashCode → int
The hash code for this object.
no setterinherited
platformVersions → List<String>?
The supported compute platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited