EncryptionConfig class

The encryption configuration for the cluster.

Constructors

EncryptionConfig({Provider? provider, List<String>? resources})
EncryptionConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
provider → Provider?
AWS Key Management Service (AWS KMS) customer master key (CMK). Either the ARN or the alias can be used.
final
resources → List<String>?
Specifies the resources to be encrypted. The only supported value is "secrets".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited