Issue class

An object representing an issue with an Amazon EKS resource.

Constructors

Issue({NodegroupIssueCode? code, String? message, List<String>? resourceIds})
Issue.fromJson(Map<String, dynamic> json)
factory

Properties

code → NodegroupIssueCode?
A brief description of the error.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The error message associated with the issue.
final
resourceIds → List<String>?
The AWS resources that are afflicted by this issue.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited