ListAddonsResponse class

Constructors

ListAddonsResponse({List<String>? addons, String? nextToken})
ListAddonsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

addons → List<String>?
A list of available add-ons.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The nextToken value returned from a previous paginated ListAddonsResponse where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited