ListClustersResponse class

Constructors

ListClustersResponse({List<String>? clusters, String? nextToken})
ListClustersResponse.fromJson(Map<String, dynamic> json)
factory

Properties

clusters → List<String>?
A list of all of the clusters for your account in the specified Region.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The nextToken value to include in a future ListClusters request. When the results of a ListClusters request exceed maxResults, you can use this value to retrieve the next page of results. This value is null when there are no more results to return.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited