LogSetup class

An object representing the enabled or disabled Kubernetes control plane logs for your cluster.

Constructors

LogSetup({bool? enabled, List<LogType>? types})
LogSetup.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool?
If a log type is enabled, that log type exports its control plane logs to CloudWatch Logs. If a log type isn't enabled, that log type doesn't export its control plane logs. Each individual log type can be enabled or disabled independently.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<LogType>?
The available cluster control plane log types.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited