Logging class

An object representing the logging configuration for resources in your cluster.

Constructors

Logging({List<LogSetup>? clusterLogging})
Logging.fromJson(Map<String, dynamic> json)
factory

Properties

clusterLogging → List<LogSetup>?
The cluster control plane logging configuration for your cluster.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited