NodegroupResources class

An object representing the resources associated with the node group, such as Auto Scaling groups and security groups for remote access.

Constructors

NodegroupResources({List<AutoScalingGroup>? autoScalingGroups, String? remoteAccessSecurityGroup})
NodegroupResources.fromJson(Map<String, dynamic> json)
factory

Properties

autoScalingGroups → List<AutoScalingGroup>?
The Auto Scaling groups associated with the node group.
final
hashCode → int
The hash code for this object.
no setterinherited
remoteAccessSecurityGroup → String?
The remote access security group associated with the node group. This security group controls SSH access to the worker nodes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited