NodegroupScalingConfig class

An object representing the scaling configuration details for the Auto Scaling group that is associated with your node group. If you specify a value for any property, then you must specify values for all of the properties.

Constructors

NodegroupScalingConfig({int? desiredSize, int? maxSize, int? minSize})
NodegroupScalingConfig.fromJson(Map<String, dynamic> json)
factory

Properties

desiredSize → int?
The current number of worker nodes that the managed node group should maintain.
final
hashCode → int
The hash code for this object.
no setterinherited
maxSize → int?
The maximum number of worker nodes that the managed node group can scale out to. Managed node groups can support up to 100 nodes by default.
final
minSize → int?
The minimum number of worker nodes that the managed node group can scale in to. This number must be greater than zero.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited