Update class

An object representing an asynchronous update.

Constructors

Update({DateTime? createdAt, List<ErrorDetail>? errors, String? id, List<UpdateParam>? params, UpdateStatus? status, UpdateType? type})
Update.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime?
The Unix epoch timestamp in seconds for when the update was created.
final
errors → List<ErrorDetail>?
Any errors associated with a Failed update.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
A UUID that is used to track the update.
final
params → List<UpdateParam>?
A key-value map that contains the parameters associated with the update.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → UpdateStatus?
The current status of the update.
final
type → UpdateType?
The type of the update.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited