UpdateLabelsPayload class

An object representing a Kubernetes label change for a managed node group.

Constructors

UpdateLabelsPayload({Map<String, String>? addOrUpdateLabels, List<String>? removeLabels})

Properties

addOrUpdateLabels → Map<String, String>?
Kubernetes labels to be added or updated.
final
hashCode → int
The hash code for this object.
no setterinherited
removeLabels → List<String>?
Kubernetes labels to be removed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited