UpdateParam class

An object representing the details of an update request.

Constructors

UpdateParam({UpdateParamType? type, String? value})
UpdateParam.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → UpdateParamType?
The keys associated with an update request.
final
value → String?
The value of the keys submitted as part of an update request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited